/*
 * GQmpeg
 * (C) 2002 John Ellis
 *
 * Author: John Ellis
 *
 * This software is released under the GNU General Public License (GNU GPL).
 * Please read the included file COPYING for more information.
 * This software comes with no warranty of any kind, use at your own risk!
 */


#ifndef MENUS_H
#define MENUS_H


GtkWidget *menu_main(UIData *ui);
GtkWidget *menu_filelist_dir(void);
GtkWidget *menu_filelist_file(void);
GtkWidget *menu_filelist_playlist(void);
GtkWidget *menu_playlist(void);
GtkWidget *menu_playlist_custom(void);


#endif
